componenttools.copy_components_and_immediate_parent_of_first_component
======================================================================

.. autofunction:: abjad.tools.componenttools.copy_components_and_immediate_parent_of_first_component.copy_components_and_immediate_parent_of_first_component
